@@ -60,12 +60,13 @@ pub struct AliyunDriveSigner {
 }
 
 pub struct AliyunDriveCore {
+    pub info: Arc<AccessorInfo>,
+
     pub endpoint: String,
     pub root: String,
     pub drive_type: DriveType,
 
     pub signer: Arc<Mutex<AliyunDriveSigner>>,
-    pub client: HttpClient,
     pub dir_lock: Arc<Mutex<()>>,
 }
 
@@ -99,9 +100,9 @@ impl AliyunDriveCore {
                     .expect("access token must be valid header value"),
             );
         }
-        let res = self.client.send(req).await?;
+        let res = self.info.http_client().send(req).await?;
         if !res.status().is_success() {
-            return Err(parse_error(res).await?);
+            return Err(parse_error(res));
         }
         Ok(res.into_body())
     }
@@ -197,6 +198,8 @@ impl AliyunDriveCore {
         })
         .map_err(new_json_serialize_error)?;
         let req = req
+            // Inject operation to the request.
+            .extension(Operation::Read)
             .body(Buffer::from(body))
             .map_err(new_request_build_error)?;
         self.send(req, token.as_deref()).await
@@ -261,6 +264,8 @@ impl AliyunDriveCore {
         })
         .map_err(new_json_serialize_error)?;
         let req = Request::post(format!("{}/adrive/v1.0/openFile/create", self.endpoint))
+            // Inject operation to the request.
+            .extension(Operation::Write)
             .body(Buffer::from(body))
             .map_err(new_request_build_error)?;
         self.send(req, token.as_deref()).await
@@ -288,6 +293,8 @@ impl AliyunDriveCore {
             "{}/adrive/v1.0/openFile/getDownloadUrl",
             self.endpoint
         ))
+        // Inject operation to the request.
+        .extension(Operation::Read)
         .body(Buffer::from(body))
         .map_err(new_request_build_error)?;
         let res = self.send(req, token.as_deref()).await?;
@@ -306,6 +313,8 @@ impl AliyunDriveCore {
         })
         .map_err(new_json_serialize_error)?;
         let req = Request::post(format!("{}/adrive/v1.0/openFile/move", self.endpoint))
+            // Inject operation to the request.
+            .extension(Operation::Write)
             .body(Buffer::from(body))
             .map_err(new_request_build_error)?;
         self.send(req, token.as_deref()).await?;
@@ -322,6 +331,8 @@ impl AliyunDriveCore {
         })
         .map_err(new_json_serialize_error)?;
         let req = Request::post(format!("{}/adrive/v1.0/openFile/update", self.endpoint))
+            // Inject operation to the request.
+            .extension(Operation::Write)
             .body(Buffer::from(body))
             .map_err(new_request_build_error)?;
         self.send(req, token.as_deref()).await?;
@@ -343,6 +354,8 @@ impl AliyunDriveCore {
         })
         .map_err(new_json_serialize_error)?;
         let req = Request::post(format!("{}/adrive/v1.0/openFile/copy", self.endpoint))
+            // Inject operation to the request.
+            .extension(Operation::Copy)
             .body(Buffer::from(body))
             .map_err(new_request_build_error)?;
         self.send(req, token.as_deref()).await
@@ -356,6 +369,8 @@ impl AliyunDriveCore {
         })
         .map_err(new_json_serialize_error)?;
         let req = Request::post(format!("{}/adrive/v1.0/openFile/delete", self.endpoint))
+            // Inject operation to the request.
+            .extension(Operation::Delete)
             .body(Buffer::from(body))
             .map_err(new_request_build_error)?;
         self.send(req, token.as_deref()).await?;
@@ -377,19 +392,8 @@ impl AliyunDriveCore {
         })
         .map_err(new_json_serialize_error)?;
         let req = Request::post(format!("{}/adrive/v1.0/openFile/list", self.endpoint))
-            .body(Buffer::from(body))
-            .map_err(new_request_build_error)?;
-        self.send(req, token.as_deref()).await
-    }
-
-    pub async fn get(&self, file_id: &str) -> Result<Buffer> {
-        let (token, drive_id) = self.get_token_and_drive().await?;
-        let body = serde_json::to_vec(&FileRequest {
-            drive_id: &drive_id,
-            file_id,
-        })
-        .map_err(new_json_serialize_error)?;
-        let req = Request::post(format!("{}/adrive/v1.0/openFile/get", self.endpoint))
+            // Inject operation to the request.
+            .extension(Operation::List)
             .body(Buffer::from(body))
             .map_err(new_request_build_error)?;
         self.send(req, token.as_deref()).await
@@ -397,6 +401,8 @@ impl AliyunDriveCore {
 
     pub async fn upload(&self, upload_url: &str, body: Buffer) -> Result<Buffer> {
         let req = Request::put(upload_url)
+            // Inject operation to the request.
+            .extension(Operation::Write)
             .body(body)
             .map_err(new_request_build_error)?;
         self.send(req, None).await
@@ -411,6 +417,8 @@ impl AliyunDriveCore {
         })
         .map_err(new_json_serialize_error)?;
         let req = Request::post(format!("{}/adrive/v1.0/openFile/complete", self.endpoint))
+            // Inject operation to the request.
+            .extension(Operation::Write)
             .body(Buffer::from(body))
             .map_err(new_request_build_error)?;
         self.send(req, token.as_deref()).await
@@ -439,6 +447,8 @@ impl AliyunDriveCore {
             "{}/adrive/v1.0/openFile/getUploadUrl",
             self.endpoint
         ))
+        // Inject operation to the request.
+        .extension(Operation::Write)
         .body(Buffer::from(body))
         .map_err(new_request_build_error)?;
         self.send(req, token.as_deref()).await
